@@ -45,6 +45,7 @@ class API:
             log_handler=None,
             host: int = 0):
 
+        self._mailbox_full = False
         self._ID = None
         if log_handler is not None and not callable(log_handler):
             raise TypeError('[PyPtt] log_handler is must callable!!')
@@ -89,7 +90,7 @@ class API:
 
         if log_level == 0:
             log_level = self.config.log_level
-        elif not lib_util.check_range(log.Level, log_level):
+        elif not lib_util.check_range(log.level, log_level):
             raise ValueError('[PyPtt] Unknown log_level', log_level)
         else:
             self.config.log_level = log_level
@@ -106,14 +107,14 @@ class API:
             self.config.log_handler = log_handler
             log.show_value(
                 self.config,
-                log.Level.INFO,
+                log.level.INFO,
                 i18n.log_handler,
                 i18n.Init
             )
         elif has_log_handler and not set_log_handler_result:
             log.show_value(
                 self.config,
-                log.Level.INFO,
+                log.level.INFO,
                 i18n.log_handler,
                 [
                     i18n.Init,
@@ -123,7 +124,7 @@ class API:
 
         if self.config.language == i18n.language.CHINESE:
             log.show_value(
-                self.config, log.Level.INFO, [
+                self.config, log.level.INFO, [
                     i18n.ChineseTranditional,
                     i18n.languageModule
                 ],
@@ -131,7 +132,7 @@ class API:
             )
         elif self.config.language == i18n.language.ENGLISH:
             log.show_value(
-                self.config, log.Level.INFO, [
+                self.config, log.level.INFO, [
                     i18n.English,
                     i18n.languageModule
                 ],
@@ -161,7 +162,7 @@ class API:
         if self.config.host == data_type.host_type.PTT1:
             log.show_value(
                 self.config,
-                log.Level.INFO,
+                log.level.INFO,
                 [
                     i18n.Connect,
                     i18n.host
@@ -171,7 +172,7 @@ class API:
         elif self.config.host == data_type.host_type.PTT2:
             log.show_value(
                 self.config,
-                log.Level.INFO,
+                log.level.INFO,
                 [
                     i18n.Connect,
                     i18n.host
@@ -181,7 +182,7 @@ class API:
         elif self.config.host == data_type.host_type.LOCALHOST:
             log.show_value(
                 self.config,
-                log.Level.INFO,
+                log.level.INFO,
                 [
                     i18n.Connect,
                     i18n.host
@@ -197,14 +198,14 @@ class API:
 
         log.show_value(
             self.config,
-            log.Level.DEBUG,
+            log.level.DEBUG,
             'ThreadID',
             self._ThreadID
         )
 
         log.show_value(
             self.config,
-            log.Level.INFO,
+            log.level.INFO,
             [
                 i18n.Library,
                 ' v ' + version.V,
@@ -218,13 +219,13 @@ class API:
             return
         log.show_value(
             self.config,
-            log.Level.DEBUG,
+            log.level.DEBUG,
             'ThreadID',
             self._ThreadID
         )
         log.show_value(
             self.config,
-            log.Level.DEBUG,
+            log.level.DEBUG,
             'Current thread id',
             current_thread_id
         )
@@ -294,7 +295,7 @@ class API:
 
     def log(self, msg: str) -> None:
         self._one_thread()
-        log.log(self.config, log.Level.INFO, msg)
+        log.log(self.config, log.level.INFO, msg)
 
     def get_time(self) -> str:
         self._one_thread()
@@ -457,7 +458,7 @@ class API:
             if need_continue:
                 log.log(
                     self.config,
-                    log.Level.DEBUG,
+                    log.level.DEBUG,
                     'Wait for retry repost'
                 )
                 time.sleep(0.1)
@@ -516,7 +517,6 @@ class API:
         check_value.check(
             self.config, int, 'index_type',
             index_type, value_class=data_type.index_type)
-        check_value.check(self.config, str, 'Board', board)
 
         try:
             from . import _api_get_newest_index
@@ -538,10 +538,14 @@ class API:
             search_condition: str = None) -> int:
         self._one_thread()
 
-        if index_type == data_type.index_type.BBS:
+        if index_type == data_type.index_type.BBS or index_type == data_type.index_type.MAIL:
             if not self._login_status:
                 raise exceptions.Requirelogin(i18n.Requirelogin)
 
+        if index_type == data_type.index_type.MAIL:
+            if self._unregistered_user:
+                raise exceptions.UnregisteredUser(lib_util.get_current_func_name())
+
         self.config.log_last_value = None
 
         try:
@@ -691,21 +695,21 @@ class API:
 
             log.show_value(
                 self.config,
-                log.Level.DEBUG,
+                log.level.DEBUG,
                 'StartIndex',
                 start_index
             )
 
             log.show_value(
                 self.config,
-                log.Level.DEBUG,
+                log.level.DEBUG,
                 'EndIndex',
                 end_index
             )
 
             error_post_list = []
             del_post_list = []
-            if self.config.log_level == log.Level.INFO:
+            if self.config.log_level == log.level.INFO:
                 PB = progressbar.ProgressBar(
                     max_value=end_index - start_index + 1,
                     redirect_stdout=True
@@ -744,7 +748,7 @@ class API:
                             raise e
                         log.log(
                             self.config,
-                            log.Level.INFO,
+                            log.level.INFO,
                             i18n.RestoreConnection
                         )
                         self._login(
@@ -758,7 +762,7 @@ class API:
                             raise e
                         log.log(
                             self.config,
-                            log.Level.INFO,
+                            log.level.INFO,
                             i18n.RestoreConnection
                         )
                         self._login(
@@ -776,7 +780,7 @@ class API:
                     if need_continue:
                         log.log(
                             self.config,
-                            log.Level.DEBUG,
+                            log.level.DEBUG,
                             'Wait for retry repost'
                         )
                         time.sleep(0.1)
@@ -784,7 +788,7 @@ class API:
 
                     break
 
-                if self.config.log_level == log.Level.INFO:
+                if self.config.log_level == log.level.INFO:
                     PB.update(index - start_index)
                 if post is None:
                     error_post_list.append(index)
@@ -798,7 +802,7 @@ class API:
                 if post.delete_status != data_type.post_delete_status.NOT_DELETED:
                     del_post_list.append(index)
                 post_handler(post)
-            if self.config.log_level == log.Level.INFO:
+            if self.config.log_level == log.level.INFO:
                 PB.finish()
 
             return error_post_list, del_post_list
@@ -832,7 +836,7 @@ class API:
             # PostAID = ""
             _url = 'https://www.ptt.cc/bbs/'
             index = str(newest_index)
-            if self.config.log_level == log.Level.INFO:
+            if self.config.log_level == log.level.INFO:
                 PB = progressbar.ProgressBar(
                     max_value=end_page - start_page + 1,
                     redirect_stdout=True
@@ -852,7 +856,7 @@ class API:
             for index in range(start_page, newest_index + 1):
                 log.show_value(
                     self.config,
-                    log.Level.DEBUG,
+                    log.level.DEBUG,
                     'CurrentPage',
                     index
                 )
@@ -892,12 +896,12 @@ class API:
                     )
                     post_handler(post)
 
-                if self.config.log_level == log.Level.INFO:
+                if self.config.log_level == log.level.INFO:
                     PB.update(index - start_page)
 
             log.show_value(
                 self.config,
-                log.Level.DEBUG,
+                log.level.DEBUG,
                 'DelPostList',
                 del_post_list
             )
@@ -905,7 +909,7 @@ class API:
             # 4. 把組合出來的 Post 塞給 handler
 
             # 5. 顯示 progress bar
-            if self.config.log_level == log.Level.INFO:
+            if self.config.log_level == log.level.INFO:
                 PB.finish()
 
             return error_post_list, del_post_list
@@ -1056,7 +1060,7 @@ class API:
         for push in push_list:
             log.show_value(
                 self.config,
-                log.Level.INFO,
+                log.level.INFO,
                 i18n.Push,
                 push
             )
@@ -1075,7 +1079,7 @@ class API:
                     # screens.show(self.config, self.connect_core.getScreenQueue())
                     log.log(
                         self.config,
-                        log.Level.INFO,
+                        log.level.INFO,
                         '等待快速推文'
                     )
                     time.sleep(5.2)
@@ -1278,6 +1282,8 @@ class API:
         check_value.check(self.config, str, 'title', title)
         check_value.check(self.config, str, 'content', content)
 
+        self.get_user(ptt_id)
+
         check_sign_file = False
         for i in range(0, 10):
             if str(i) == sign_file or i == sign_file:
@@ -1307,6 +1313,10 @@ class API:
             content,
             sign_file)
 
+        if self._mailbox_full:
+            self.logout()
+            raise exceptions.MailboxFull()
+
     def has_new_mail(self) -> int:
         self._one_thread()
 
@@ -1581,6 +1591,47 @@ class API:
 
         return _api_get_board_info.get_board_info(self, board, call_by_others)
 
+    def get_mail(self, index):
+
+        self._one_thread()
+
+        if not self._login_status:
+            raise exceptions.Requirelogin(i18n.Requirelogin)
+
+        if self._unregistered_user:
+            raise exceptions.UnregisteredUser(lib_util.get_current_func_name())
+
+        current_index = self.get_newest_index(data_type.index_type.MAIL)
+
+        check_value.check_index(self.config, index, current_index)
+
+        try:
+            from . import _api_mail
+        except ModuleNotFoundError:
+            import _api_mail
+
+        return _api_mail.get_mail(self, index)
+
+    def del_mail(self, index):
+        self._one_thread()
+
+        if not self._login_status:
+            raise exceptions.Requirelogin(i18n.Requirelogin)
+
+        if self._unregistered_user:
+            raise exceptions.UnregisteredUser(lib_util.get_current_func_name())
+
+        current_index = self.get_newest_index(data_type.index_type.MAIL)
+
+        check_value.check_index(self.config, index, current_index)
+
+        try:
+            from . import _api_mail
+        except ModuleNotFoundError:
+            import _api_mail
+
+        return _api_mail.del_mail(self, index)
+
 
 if __name__ == '__main__':
     print('PyPtt v ' + version.V)
