@@ -40,7 +40,7 @@ def logout(api) -> None:
 
     log.log(
         api.config,
-        log.Level.INFO,
+        log.level.INFO,
         [
             i18n.Start,
             i18n.logout
@@ -59,7 +59,7 @@ def logout(api) -> None:
 
     log.show_value(
         api.config,
-        log.Level.INFO,
+        log.level.INFO,
         i18n.logout,
         i18n.Done
     )
@@ -86,6 +86,10 @@ def login(
             return 'y' + command.Enter
         return 'n' + command.Enter
 
+    api._mailbox_full = False
+    def mailbox_full():
+        api._mailbox_full = True
+
     if len(password) > 8:
         password = password[:8]
 
@@ -101,7 +105,7 @@ def login(
 
     log.show_value(
         api.config,
-        log.Level.INFO,
+        log.level.INFO,
         [
             i18n.login,
             i18n.ID
@@ -115,6 +119,12 @@ def login(
             screens.Target.MainMenu,
             break_detect=True
         ),
+        connect_core.TargetUnit(
+            i18n.MailBoxFull,
+            '【郵件選單】',
+            response=command.GoMainMenu_TypeQ,
+            handler=mailbox_full
+        ),
         connect_core.TargetUnit(
             i18n.HasNewMailGotoMainMenu,
             '你有新信件',
@@ -148,11 +158,6 @@ def login(
             '您要刪除以上錯誤嘗試的記錄嗎',
             response='y' + command.Enter,
         ),
-        connect_core.TargetUnit(
-            i18n.MailBoxFull,
-            '您保存信件數目',
-            response=command.GoMainMenu,
-        ),
         connect_core.TargetUnit(
             i18n.PostNotFinish,
             '請選擇暫存檔 (0-9)[0]',
@@ -181,6 +186,11 @@ def login(
             i18n.SigningUpdate,
             '正在更新與同步線上使用者及好友名單',
         ),
+        connect_core.TargetUnit(
+            i18n.GoMainMenu,
+            '【分類看板】',
+            response=command.GoMainMenu,
+        ),
     ]
 
     cmd_list = []
@@ -209,14 +219,14 @@ def login(
         api.cursor = data_type.Cursor.NEW
         log.log(
             api.config,
-            log.Level.DEBUG,
+            log.level.DEBUG,
             i18n.NewCursor
         )
     else:
         api.cursor = data_type.Cursor.OLD
         log.log(
             api.config,
-            log.Level.DEBUG,
+            log.level.DEBUG,
             i18n.OldCursor
         )
 
@@ -235,7 +245,7 @@ def login(
         # print(ori_screen)
         log.log(
             api.config,
-            log.Level.INFO,
+            log.level.INFO,
             i18n.UnregisteredUserCantUseAllAPI
         )
 
